import events = require('@aws-cdk/aws-events');
import { Construct, IResource, Resource } from '@aws-cdk/cdk';
export interface IRepository extends IResource {
    /** The ARN of this Repository. */
    readonly repositoryArn: string;
    /** The human-visible name of this Repository. */
    readonly repositoryName: string;
    /** The HTTP clone URL */
    readonly repositoryCloneUrlHttp: string;
    /** The SSH clone URL */
    readonly repositoryCloneUrlSsh: string;
    /**
     * Defines a CloudWatch event rule which triggers for repository events. Use
     * `rule.addEventPattern(pattern)` to specify a filter.
     */
    onEvent(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a "CodeCommit
     * Repository State Change" event occurs.
     */
    onStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * created (i.e. a new branch/tag is created) to the repository.
     */
    onReferenceCreated(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * updated (i.e. a commit is pushed to an existing or new branch) from the repository.
     */
    onReferenceUpdated(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * delete (i.e. a branch/tag is deleted) from the repository.
     */
    onReferenceDeleted(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a pull request state is changed.
     */
    onPullRequestStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a comment is made on a pull request.
     */
    onCommentOnPullRequest(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a comment is made on a commit.
     */
    onCommentOnCommit(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a commit is pushed to a branch.
     * @param target The target of the event
     * @param branch The branch to monitor. Defaults to all branches.
     */
    onCommit(name: string, target?: events.IEventRuleTarget, branch?: string): events.EventRule;
    /**
     * Exports this Repository. Allows the same Repository to be used in 2 different Stacks.
     *
     * @see import
     */
    export(): RepositoryImportProps;
}
/**
 * Properties for the {@link Repository.import} method.
 */
export interface RepositoryImportProps {
    /**
     * The name of an existing CodeCommit Repository that we are referencing.
     * Must be in the same account and region as the root Stack.
     */
    readonly repositoryName: string;
}
/**
 * Represents a reference to a CodeCommit Repository.
 *
 * If you want to create a new Repository managed alongside your CDK code,
 * use the {@link Repository} class.
 *
 * If you want to reference an already existing Repository,
 * use the {@link Repository.import} method.
 */
export declare abstract class RepositoryBase extends Resource implements IRepository {
    /** The ARN of this Repository. */
    abstract readonly repositoryArn: string;
    /** The human-visible name of this Repository. */
    abstract readonly repositoryName: string;
    /** The HTTP clone URL */
    abstract readonly repositoryCloneUrlHttp: string;
    /** The SSH clone URL */
    abstract readonly repositoryCloneUrlSsh: string;
    abstract export(): RepositoryImportProps;
    /**
     * Defines a CloudWatch event rule which triggers for repository events. Use
     * `rule.addEventPattern(pattern)` to specify a filter.
     */
    onEvent(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a "CodeCommit
     * Repository State Change" event occurs.
     */
    onStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * created (i.e. a new branch/tag is created) to the repository.
     */
    onReferenceCreated(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * updated (i.e. a commit is pushed to an existing or new branch) from the repository.
     */
    onReferenceUpdated(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a reference is
     * delete (i.e. a branch/tag is deleted) from the repository.
     */
    onReferenceDeleted(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a pull request state is changed.
     */
    onPullRequestStateChange(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a comment is made on a pull request.
     */
    onCommentOnPullRequest(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a comment is made on a commit.
     */
    onCommentOnCommit(name: string, target?: events.IEventRuleTarget, options?: events.EventRuleProps): events.EventRule;
    /**
     * Defines a CloudWatch event rule which triggers when a commit is pushed to a branch.
     * @param target The target of the event
     * @param branch The branch to monitor. Defaults to all branches.
     */
    onCommit(name: string, target?: events.IEventRuleTarget, branch?: string): events.EventRule;
}
export interface RepositoryProps {
    /**
     * Name of the repository. This property is required for all repositories.
     */
    readonly repositoryName: string;
    /**
     * A description of the repository. Use the description to identify the
     * purpose of the repository.
     */
    readonly description?: string;
}
/**
 * Provides a CodeCommit Repository
 */
export declare class Repository extends RepositoryBase {
    /**
     * Import a Repository defined either outside the CDK, or in a different Stack
     * (exported with the {@link export} method).
     *
     * @param scope the parent Construct for the Repository
     * @param id the name of the Repository Construct
     * @param props the properties used to identify the existing Repository
     * @returns a reference to the existing Repository
     */
    static import(scope: Construct, id: string, props: RepositoryImportProps): IRepository;
    private readonly repository;
    private readonly triggers;
    constructor(scope: Construct, id: string, props: RepositoryProps);
    readonly repositoryArn: string;
    readonly repositoryCloneUrlHttp: string;
    readonly repositoryCloneUrlSsh: string;
    readonly repositoryName: string;
    /**
     * Exports this Repository. Allows the same Repository to be used in 2 different Stacks.
     *
     * @see import
     */
    export(): RepositoryImportProps;
    /**
     * Create a trigger to notify another service to run actions on repository events.
     * @param arn   Arn of the resource that repository events will notify
     * @param options Trigger options to run actions
     */
    notify(arn: string, options?: RepositoryTriggerOptions): Repository;
}
/**
 * Creates for a repository trigger to an SNS topic or Lambda function.
 */
export interface RepositoryTriggerOptions {
    /**
     * A name for the trigger.Triggers on a repository must have unique names
     */
    readonly name?: string;
    /**
     * The repository events for which AWS CodeCommit sends information to the
     * target, which you specified in the DestinationArn property.If you don't
     * specify events, the trigger runs for all repository events.
     */
    readonly events?: RepositoryEventTrigger[];
    /**
     * The names of the branches in the AWS CodeCommit repository that contain
     * events that you want to include in the trigger. If you don't specify at
     * least one branch, the trigger applies to all branches.
     */
    readonly branches?: string[];
    /**
     * When an event is triggered, additional information that AWS CodeCommit
     * includes when it sends information to the target.
     */
    readonly customData?: string;
}
/**
 * Repository events that will cause the trigger to run actions in another service.
 */
export declare enum RepositoryEventTrigger {
    All = "all",
    UpdateRef = "updateReference",
    CreateRef = "createReference",
    DeleteRef = "deleteReference"
}
